﻿* Encoding: UTF-8.
*Additivity Dominance: Study  5
*Created by S.S.

*Excluding participants who didn't finish

USE ALL.
COMPUTE filter_$=(excl.finish = 0).
VARIABLE LABELS filter_$ 'excl.finish = 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

FREQUENCIES VARIABLES=excl.scale
  /ORDER=ANALYSIS.

*Excluding participants who didn't finish or didn't fill out scale intro correctly*

USE ALL.
COMPUTE filter_$=(excl.finish = 0 & excl.scale = 0).
VARIABLE LABELS filter_$ 'excl.finish = 0 & excl.scale = 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

*Age and Gender Descriptives*

FREQUENCIES VARIABLES=gender
  /ORDER=ANALYSIS.

DESCRIPTIVES VARIABLES=age
  /STATISTICS=MEAN STDDEV MIN MAX.

*Compute average natural rating for no intervention, one process 5% added, one process 15% added, and three process 15% add*

COMPUTE average.base=(base.milk+base.oraj)/2.
EXECUTE.

COMPUTE average.onedose.low=(onedose.low.fat+onedose.low.cal+onedose.low.pul)/3.
EXECUTE.

COMPUTE average.onedose.high=(onedose.high.fat+onedose.high.cal+onedose.high.pul)/3.
EXECUTE.

COMPUTE average.threedose.high=(threedose.high.fat+threedose.high.cal+threedose.high.pul)/3.
EXECUTE.

*Average reduction in naturalness base vs. intervention, tripling dose, and tripling process(

T-TEST PAIRS=average.base average.onedose.low average.onedose.high WITH average.onedose.low 
    average.onedose.high average.threedose.high (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

*First addition: effect by example/product*

T-TEST PAIRS= base.milk base.milk base.oraj WITH onedose.low.fat onedose.low.cal onedose.low.pul (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE firstadd.fat = base.milk-onedose.low.fat.
COMPUTE firstadd.cal = base.milk-onedose.low.cal.
COMPUTE firstadd.pul = base.oraj-onedose.low.pul.
DESCRIPTIVES VARIABLES=firstadd.fat firstadd.cal firstadd.pul
  /STATISTICS=MEAN STDDEV SEMEAN. /* divide mean by SD for repeated measures cohen's d.

*Triple dose: effect by example/product*

T-TEST PAIRS=onedose.low.fat onedose.low.cal onedose.low.pul WITH onedose.high.fat onedose.high.cal 
    onedose.high.pul (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE tripledose.fat = onedose.low.fat-onedose.high.fat.
COMPUTE tripledose.cal = onedose.low.cal-onedose.high.cal.
COMPUTE tripledose.pul = onedose.low.pul-onedose.high.pul.
DESCRIPTIVES VARIABLES=tripledose.fat tripledose.cal tripledose.pul
  /STATISTICS=MEAN STDDEV SEMEAN. /* divide mean by SD for repeated measures cohen's d.

*Triple process: effect by example/product*

T-TEST PAIRS=onedose.high.fat onedose.high.cal onedose.high.pul WITH threedose.high.fat 
    threedose.high.cal threedose.high.pul (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

COMPUTE tripleprocess.fat = onedose.high.fat-threedose.high.fat.
COMPUTE tripleprocess.cal = onedose.high.cal-threedose.high.cal.
COMPUTE tripleprocess.pul = onedose.high.pul-threedose.high.pul.
DESCRIPTIVES VARIABLES=tripleprocess.fat tripleprocess.cal tripleprocess.pul
  /STATISTICS=MEAN STDDEV SEMEAN. /*  mean by SD for repeated measures cohen's d.

*Naturalness of baseline beverages*

DESCRIPTIVES VARIABLES=base.milk base.oraj
  /STATISTICS=MEAN STDDEV MIN MAX.
