﻿* Encoding: UTF-8.
*Additivity Dominance: Study S1
*Created by S.S.

*Excluding participants who didn't finish 

USE ALL.
COMPUTE filter_$=(excl.finish = 0).
VARIABLE LABELS filter_$ 'excl.finish = 0 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

*Demographics 

FREQUENCIES VARIABLES=gender
  /ORDER=ANALYSIS.

DESCRIPTIVES VARIABLES=age
  /STATISTICS=MEAN STDDEV MIN MAX.

*Calculate difference and composite variables

COMPUTE milk.fat.diff = milk.fat.rem-milk.fat.add. 
COMPUTE milk.sug.diff = milk.sug.rem-milk.sug.add. 
COMPUTE milk.cal.diff = milk.cal.rem-milk.cal.add. 
COMPUTE oj.pul.diff = oj.pul.rem-oj.pul.add. 
COMPUTE oj.vc.diff = oj.vic.rem-oj.vic.add. 
COMPUTE ave.add=((milk.fat.rem-milk.fat.add)+(milk.sug.rem-milk.sug.add)+(milk.cal.rem-milk.cal.add)+
    (oj.pul.rem-oj.pul.add)+(oj.vic.rem-oj.vic.add))/5.
COMPUTE ave.rem=((milk.organ-milk.fat.rem)+(milk.organ-milk.sug.rem)+(milk.organ-milk.cal.rem)+
    (oj.organ-oj.pul.rem)+(oj.organ-oj.vic.rem))/5.   
EXECUTE.   

*Are beverages with something added less natural than those with the same thing removed? And, is the additive effect different depending on scale training?

GLM milk.fat.rem milk.fat.add milk.sug.rem milk.sug.add milk.cal.rem milk.cal.add oj.pul.rem 
    oj.pul.add oj.vic.rem oj.vic.add BY ScaleTraining
  /WSFACTOR=BeveragePair 5 Polynomial Process 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=BeveragePair Process BeveragePair*Process
  /DESIGN=ScaleTraining.

SORT CASES  BY ScaleTraining.
SPLIT FILE SEPARATE BY ScaleTraining.

GLM milk.fat.rem milk.fat.add milk.sug.rem milk.sug.add milk.cal.rem milk.cal.add oj.pul.rem 
    oj.pul.add oj.vic.rem oj.vic.add
  /WSFACTOR=BeveragePair 5 Polynomial Process 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=DESCRIPTIVE ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=BeveragePair Process BeveragePair*Process.

T-TEST PAIRS=milk.fat.rem milk.sug.rem milk.cal.rem oj.pul.rem oj.vic.rem WITH milk.fat.add 
    milk.sug.add milk.cal.add oj.pul.add oj.vic.add (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

DESCRIPTIVES VARIABLES=milk.fat.diff milk.sug.diff milk.cal.diff oj.pul.diff oj.vc.diff 
  /STATISTICS=MEAN STDDEV. /*Mean divided by SD is cohen's d for repeated measures.

*How much does any intervention (adding or removing) affect naturalness relative to no intervention?

DESCRIPTIVES VARIABLES=milk.organ oj.organ milk.regul oj.regul ave.rem ave.add
  /STATISTICS=MEAN STDDEV MIN MAX.

SPLIT FILE OFF.


